@@ -48,7 +48,7 @@ mapmap CLASSTN*:paths[]   @stmt   @token @new
 weave ANY:aspect CMETHODN:method @stmt @token @new
 aspect TYPEN:type cmethod.. CLASSN:class METHODN:method STT_DECL:params {:instmt  @stmt @token @new
 
-block {:block @stmt @token @new
+block {:block @stmt @new
 
 if pexpr:bool {:truecase else.. {:falsecase  @stmt @token @new @name @cmpl
 else @token
