@@ -129,6 +129,9 @@ void knh_ClassMap_sort(Ctx *ctx, ClassMap *o);
 void knh_ClassMap_add(Ctx *ctx, ClassMap *o, Mapper *map);
 void knh_ClassMap__dump(Ctx *ctx, ClassMap *o, OutputStream *w, String *m);
 void knh_ClassMap__man(Ctx *ctx, ClassMap *o, OutputStream *w, knh_class_t cid);
+int konoha_addClassConst(Ctx *ctx, knh_class_t cid, String* name, Object *value);
+int konoha_existsClassConst(Ctx *ctx, knh_class_t cid, knh_bytes_t name);
+Object *konoha_getClassConst(Ctx *ctx, knh_class_t cid, knh_bytes_t name);
 /* ../src/class/knh_Class_type_t.c */
 knh_class_t knh_pmztype_toclass(Ctx *ctx, knh_type_t t, knh_class_t this_cid);
 knh_type_t knh_pmztype_totype(Ctx *ctx, knh_type_t t, knh_class_t this_cid);
@@ -259,6 +262,11 @@ Iterator* new_Iterator(Ctx *ctx, knh_class_t p1, Any *source, knh_fitrnext fnext
 Mapper* new_Mapper(Ctx *ctx, knh_flag_t flag, knh_class_t scid, knh_class_t tcid, knh_fmapper fmap, Object *mapdata);
 Mapper* new_MapMap(Ctx *ctx, Mapper *m1, Mapper *m2);
 void knh_Mapper__k(Ctx *ctx, Mapper *o, OutputStream *w, String *m);
+void konoha_addMapper(Ctx *ctx, knh_flag_t flag, knh_type_t stype, knh_type_t ttype, knh_fmapper fmap, Object *mapdata);
+MAPPER knh_Mapper_fInterface(Ctx *ctx, knh_sfp_t *sfp);
+MAPPER knh_fmapper_null(Ctx *ctx, knh_sfp_t *sfp);
+knh_bool_t knh_Mapper_isNoSuchMapping(Mapper *mpr);
+Mapper *knh_tMapper_find_(Ctx *ctx, knh_class_t scid, knh_class_t tcid, int isgen);
 /* ../src/class/knh_Method.c */
 MethodField* new_MethodField(Ctx *ctx, knh_type_t rtype, size_t psize);
 knh_hcode_t knh_mparam_hcode(knh_hcode_t h, knh_type_t type, knh_fieldn_t fn);
@@ -322,7 +330,7 @@ knh_bool_t knh_Object_equals(Ctx *ctx, Object *o1, Object *o2);
 knh_bytes_t knh_Object_tobytes(Ctx *ctx, Object *o);
 /* ../src/class/knh_OutputStream.c */
 Object *knh_OutputStream_open(Ctx *ctx, OutputStream *o, String *urn, String *mode);
-void knh_OutputStream_putc(Ctx *ctx, OutputStream *o, int ch);
+void knh_OutputStream_putc(Ctx *ctx, OutputStream *o, knh_int_t ch);
 void knh_OutputStream_write(Ctx *ctx, OutputStream *o, knh_bytes_t buf);
 void knh_OutputStream_flush(Ctx *ctx, OutputStream *o);
 void knh_OutputStream_clear(Ctx *ctx, OutputStream *o);
@@ -367,41 +375,38 @@ knh_type_t knh_ResultSet_get_type(Ctx *ctx, ResultSet *o, size_t n);
 knh_int_t knh_ResultSet_getInt(Ctx *ctx, ResultSet *o, size_t n);
 knh_float_t knh_ResultSet_getFloat(Ctx *ctx, ResultSet *o, size_t n);
 String* knh_ResultSet_getString(Ctx *ctx, ResultSet *o, size_t n);
-/* ../src/class/knh_Runtime.c */
-knh_bytes_t knh_Runtime_aliasURN(Ctx *ctx, knh_bytes_t aurn);
-void knh_Runtime_setAliasURN(Ctx *ctx, String *alias, String *urn);
 /* ../src/class/knh_Script.c */
 Script *knh_NameSpace_getScript(Ctx *ctx, NameSpace *ns);
 void knh_Script__k(Ctx *ctx, Script *o, OutputStream *w, String *m);
 void knh_Script__dump(Ctx *ctx, Script *o, OutputStream *w, String *m);
 /* ../src/class/knh_String.c */
-knh_hcode_t knh_string_hash(knh_uchar_t *buf, size_t len);
+knh_hcode_t knh_uchar_hcode(knh_hcode_t h, knh_uchar_t *buf, size_t len);
 void knh_String_checkASCII(String *o);
-knh_String_t *new_StringX__T(Ctx *ctx, knh_class_t cid, char *text);
+knh_String_t *new_StringX__T(Ctx *ctx, knh_class_t cid, const char *text);
 String *new_StringX__fast(Ctx *ctx, knh_class_t cid, knh_bytes_t t, String *orign);
-String *new_StringX__FormatException(Ctx *ctx, knh_class_t cid, knh_bytes_t t, String *orign);
 String *new_StringX(Ctx *ctx, knh_class_t cid, knh_bytes_t t, String *orign);
-String *new_String__integer(Ctx *ctx, knh_int_t n);
+String *new_String__int(Ctx *ctx, knh_int_t n);
 String *new_String__float(Ctx *ctx, knh_float_t n);
 char *knh_StringNULL_tochar(String *o);
 knh_bool_t knh_String_equals(String *o, knh_bytes_t s);
 knh_bool_t knh_String_startsWith(String *b, knh_bytes_t s);
 knh_bool_t knh_String_endsWith(String *b, knh_bytes_t s);
+Object* new_String_parseOf(Ctx *ctx, String *p);
+Object *new_Object_parseOf(Ctx *ctx, String *s);
 /* ../src/class/knh_String_mbytes.c */
 knh_bool_t knh_bytes_checkENCODING(knh_bytes_t s);
 size_t knh_bytes_mlen(knh_bytes_t s);
 knh_bytes_t knh_bytes_mofflen(knh_bytes_t m, size_t moff, size_t mlen);
-/* ../src/class/knh_StringParser.c */
-Object* new_String_parseOf(Ctx *ctx, String *p);
-knh_type_t	knh_ObjectParser_typing(Ctx *ctx, knh_bytes_t t);
-Object *new_Object_parseOf(Ctx *ctx, String *s);
 /* ../src/class/knh_StringUnit.c */
 StringUnit *new_StringUnit(Ctx *ctx, knh_flag_t flag, knh_class_t cid, String *tag);
+String *new_StringX__FormatException(Ctx *ctx, knh_class_t cid, knh_bytes_t t, String *orign);
 /* ../src/class/knh_System.c */
 char * knh_bytes_nzenvkey(knh_bytes_t t, char *buf, size_t bufsiz);
 Any* knh_System_getProperty(Ctx *ctx, System *o, knh_bytes_t key);
 void knh_System_setProperty(Ctx *ctx, System *o, String *key, Any *value);
 knh_bool_t konoha_initcheck(void);
+knh_bytes_t knh_Runtime_aliasURN(Ctx *ctx, knh_bytes_t aurn);
+void knh_Runtime_setAliasURN(Ctx *ctx, String *alias, String *urn);
 /* ../src/class/knh_Tuple2.c */
 Tuple2 *new_Tuple2(Ctx *ctx, Object *first, Object *second);
 /* ../src/compiler/asm.c */
@@ -447,7 +452,7 @@ int knh_Stmt_complie(Ctx *ctx, Stmt *stmt, String *nsname, int isEval);
 Stmt *knh_bytes_parseStmt(Ctx *ctx, knh_bytes_t kscript);
 void konohac_eval(Ctx *ctx, String *nsname, InputStream *in);
 void knh_Asm_openlib(Ctx *ctx, Asm *abr, knh_bytes_t fpath);
-int knh_NameSpace_load(Ctx *ctx, NameSpace *ns, knh_bytes_t fpath, int isEval);
+int knh_NameSpace_loadScript(Ctx *ctx, NameSpace *ns, knh_bytes_t fpath, int isEval);
 void konoha_compile(Ctx *ctx, String *nsname, knh_bytes_t fpath);
 /* ../src/compiler/parser.c */
 Stmt *new_StmtINSTMT(Ctx *ctx, Token *tk);
@@ -545,7 +550,7 @@ int knh_isfile(Ctx *ctx, knh_bytes_t path);
 int knh_isdir(Ctx *ctx, knh_bytes_t path);
 int knh_isnewerfile(Ctx *ctx, char *path, char *path2);
 knh_uint_t knh_initseed();
-knh_uint64_t knh_timecount();
+knh_uint64_t konoha_gettime();
 /* ../src/deps/tbmx1.c */
 void *knh_dlopen(Ctx *ctx, const char* path, int mode);
 void *knh_dlsym(Ctx *ctx, void* handle, const char* symbol);
@@ -554,7 +559,7 @@ int knh_dlclose(Ctx *ctx, void* handle);
 char * knh_format_homepath(char *buf, size_t bufsiz);
 /* ../src/deps/thread.c */
 knh_thread_t knh_thread_self();
-int thread_create(knh_thread_t *thread, void *attr, void *(*start_routine)(void *), void * arg);
+int thread_create(knh_thread_t *thread, void *attr, void *(*frun)(void *), void * arg);
 int knh_thread_key_create(knh_thread_key_t *key);
 int knh_thread_setspecific(knh_thread_key_t key, const void *data);
 void* knh_thread_getspecific(knh_thread_key_t key);
@@ -568,7 +573,7 @@ char * knh_format_homepath(char *buf, size_t bufsiz);
 int knh_isfile(Ctx *ctx, knh_bytes_t path);
 int knh_isdir(Ctx *ctx, knh_bytes_t path);
 knh_uint_t knh_initseed();
-knh_uint64_t knh_timecount();
+knh_uint64_t konoha_gettime();
 /* ../src/konoha.c */
 int main(int argc, char **argv);
 /* ../src/labs/b4.c */
@@ -576,6 +581,10 @@ METHOD knh__Script_initfibo(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Script_fibo(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Script_changeChannel(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Script_hook(Ctx *ctx, knh_sfp_t *sfp);
+/* ../src/main/filesystem.c */
+char * knh_format_parentpath(char *buf, size_t bufsiz, knh_bytes_t path, int n);
+char * knh_format_nzpath(char *buf, size_t bufsiz, knh_bytes_t path);
+char * knh_format_catpath(char *buf, size_t bufsiz, knh_bytes_t path, knh_bytes_t file);
 /* ../src/main/glue.c */
 int knh_fcallback_cmpr(Object *obj, Object *obj2);
 void *konoha_generateCallBackFunc(Ctx *ctx, void *func, Closure *c);
@@ -585,12 +594,6 @@ void KNH_ICLASS(Ctx *ctx, knh_class_t cid, knh_class_t p1);
 knh_class_t KNH_XCLASS(Ctx *ctx, knh_class_t cid, knh_class_t bcid, ClassSpec *cs);
 knh_class_t konoha_getcid(Ctx *ctx, char *lname);
 knh_class_t konoha_findcid(Ctx *ctx, knh_bytes_t lname);
-/* ../src/main/knh_tMapper.c */
-void konoha_addMapper(Ctx *ctx, knh_flag_t flag, knh_type_t stype, knh_type_t ttype, knh_fmapper fmap, Object *mapdata);
-MAPPER knh_Mapper_fInterface(Ctx *ctx, knh_sfp_t *sfp);
-MAPPER knh_fmapper_null(Ctx *ctx, knh_sfp_t *sfp);
-knh_bool_t knh_Mapper_isNoSuchMapping(Mapper *mpr);
-Mapper *knh_tMapper_find_(Ctx *ctx, knh_class_t scid, knh_class_t tcid, int isgen);
 /* ../src/main/konoha_api.c */
 void konoha_init(void);
 int knh_readline_askYesNo(char *prompt, int def);
@@ -610,15 +613,11 @@ void knh_srand(knh_uint_t seed);
 METHOD knh__System_setRandomSeed(Ctx *ctx, knh_sfp_t *sfp);
 knh_uint_t knh_rand();
 knh_float_t knh_float_rand();
-/* ../src/main/konoha_file.c */
-char * knh_format_parentpath(char *buf, size_t bufsiz, knh_bytes_t path, int n);
-char * knh_format_nzpath(char *buf, size_t bufsiz, knh_bytes_t path);
-char * knh_format_catpath(char *buf, size_t bufsiz, knh_bytes_t path, knh_bytes_t file);
 /* ../src/main/konoha_libknh.c */
 /* ../src/main/konoha_locale.c */
 char *konoha_encoding();
 char *knh_format_lang(char *buf, size_t bufsiz);
-/* ../src/main/konoha_print.c */
+/* ../src/main/logging.c */
 void knh_stack_pmsg(Ctx *ctx, knh_sfp_t *sfp, knh_flag_t flag, String *s);
 void knh_stack_p(Ctx *ctx, knh_sfp_t *sfp, knh_flag_t flag, knh_methodn_t mn, int sfpidx);
 int knh_verbose(void);
