@@ -48,6 +48,15 @@ knh_code_t* KNH_ASM_XMOVo_(Ctx *ctx, Asm *o,knh_sfx_t a1,Object* a2);
 knh_code_t* KNH_ASM_XMOVx_(Ctx *ctx, Asm *o,knh_sfx_t a1,knh_sfx_t a2);
 knh_code_t* KNH_ASM_XMOVDEF_(Ctx *ctx, Asm *o,knh_sfx_t a1,knh_class_t a2);
 knh_code_t* KNH_ASM_XMOVSYS_(Ctx *ctx, Asm *o,knh_sfx_t a1,knh_ushort_t a2);
+knh_code_t* KNH_ASM_MOVxi_(Ctx *ctx, Asm *o,knh_sfi_t a1,knh_sfx_t a2);
+knh_code_t* KNH_ASM_XMOVsi_(Ctx *ctx, Asm *o,knh_sfx_t a1,knh_sfi_t a2);
+knh_code_t* KNH_ASM_XMOVxi_(Ctx *ctx, Asm *o,knh_sfx_t a1,knh_sfx_t a2);
+knh_code_t* KNH_ASM_MOVxf_(Ctx *ctx, Asm *o,knh_sfi_t a1,knh_sfx_t a2);
+knh_code_t* KNH_ASM_XMOVsf_(Ctx *ctx, Asm *o,knh_sfx_t a1,knh_sfi_t a2);
+knh_code_t* KNH_ASM_XMOVxf_(Ctx *ctx, Asm *o,knh_sfx_t a1,knh_sfx_t a2);
+knh_code_t* KNH_ASM_MOVxb_(Ctx *ctx, Asm *o,knh_sfi_t a1,knh_sfx_t a2);
+knh_code_t* KNH_ASM_XMOVsb_(Ctx *ctx, Asm *o,knh_sfx_t a1,knh_sfi_t a2);
+knh_code_t* KNH_ASM_XMOVxb_(Ctx *ctx, Asm *o,knh_sfx_t a1,knh_sfx_t a2);
 knh_code_t* KNH_ASM_SWAP_(Ctx *ctx, Asm *o,knh_sfi_t a1,knh_sfi_t a2);
 knh_code_t* KNH_ASM_PINIo_(Ctx *ctx, Asm *o,knh_sfi_t a1,Object* a2);
 knh_code_t* KNH_ASM_SETESP_(Ctx *ctx, Asm *o,knh_sfi_t a1);
@@ -308,7 +317,124 @@ typedef struct {
 
 #define OPSIZE_XMOVSYS  (sizeof(klr_xmovsys_t)-sizeof(void*))
 
-#define OPCODE_SWAP ((knh_opcode_t)12)
+#define OPCODE_MOVXI ((knh_opcode_t)12)
+typedef struct {
+#ifdef KNH_USING_THREADEDCODE
+	void *codeaddr;
+#endif/*KNH_USING_THREADEDCODE*/
+	knh_opcode_t opcode;
+	knh_sfi_t a1;
+	knh_sfx_t a2;
+	void *nextaddr;
+} klr_movxi_t;
+
+#define OPSIZE_MOVXI  (sizeof(klr_movxi_t)-sizeof(void*))
+
+#define OPCODE_XMOVSI ((knh_opcode_t)13)
+typedef struct {
+#ifdef KNH_USING_THREADEDCODE
+	void *codeaddr;
+#endif/*KNH_USING_THREADEDCODE*/
+	knh_opcode_t opcode;
+	knh_sfx_t a1;
+	knh_sfi_t a2;
+	void *nextaddr;
+} klr_xmovsi_t;
+
+#define OPSIZE_XMOVSI  (sizeof(klr_xmovsi_t)-sizeof(void*))
+
+#define OPCODE_XMOVXI ((knh_opcode_t)14)
+typedef struct {
+#ifdef KNH_USING_THREADEDCODE
+	void *codeaddr;
+#endif/*KNH_USING_THREADEDCODE*/
+	knh_opcode_t opcode;
+	knh_sfx_t a1;
+	knh_sfx_t a2;
+	void *nextaddr;
+} klr_xmovxi_t;
+
+#define OPSIZE_XMOVXI  (sizeof(klr_xmovxi_t)-sizeof(void*))
+
+#define OPCODE_MOVXF ((knh_opcode_t)15)
+typedef struct {
+#ifdef KNH_USING_THREADEDCODE
+	void *codeaddr;
+#endif/*KNH_USING_THREADEDCODE*/
+	knh_opcode_t opcode;
+	knh_sfi_t a1;
+	knh_sfx_t a2;
+	void *nextaddr;
+} klr_movxf_t;
+
+#define OPSIZE_MOVXF  (sizeof(klr_movxf_t)-sizeof(void*))
+
+#define OPCODE_XMOVSF ((knh_opcode_t)16)
+typedef struct {
+#ifdef KNH_USING_THREADEDCODE
+	void *codeaddr;
+#endif/*KNH_USING_THREADEDCODE*/
+	knh_opcode_t opcode;
+	knh_sfx_t a1;
+	knh_sfi_t a2;
+	void *nextaddr;
+} klr_xmovsf_t;
+
+#define OPSIZE_XMOVSF  (sizeof(klr_xmovsf_t)-sizeof(void*))
+
+#define OPCODE_XMOVXF ((knh_opcode_t)17)
+typedef struct {
+#ifdef KNH_USING_THREADEDCODE
+	void *codeaddr;
+#endif/*KNH_USING_THREADEDCODE*/
+	knh_opcode_t opcode;
+	knh_sfx_t a1;
+	knh_sfx_t a2;
+	void *nextaddr;
+} klr_xmovxf_t;
+
+#define OPSIZE_XMOVXF  (sizeof(klr_xmovxf_t)-sizeof(void*))
+
+#define OPCODE_MOVXB ((knh_opcode_t)18)
+typedef struct {
+#ifdef KNH_USING_THREADEDCODE
+	void *codeaddr;
+#endif/*KNH_USING_THREADEDCODE*/
+	knh_opcode_t opcode;
+	knh_sfi_t a1;
+	knh_sfx_t a2;
+	void *nextaddr;
+} klr_movxb_t;
+
+#define OPSIZE_MOVXB  (sizeof(klr_movxb_t)-sizeof(void*))
+
+#define OPCODE_XMOVSB ((knh_opcode_t)19)
+typedef struct {
+#ifdef KNH_USING_THREADEDCODE
+	void *codeaddr;
+#endif/*KNH_USING_THREADEDCODE*/
+	knh_opcode_t opcode;
+	knh_sfx_t a1;
+	knh_sfi_t a2;
+	void *nextaddr;
+} klr_xmovsb_t;
+
+#define OPSIZE_XMOVSB  (sizeof(klr_xmovsb_t)-sizeof(void*))
+
+#define OPCODE_XMOVXB ((knh_opcode_t)20)
+typedef struct {
+#ifdef KNH_USING_THREADEDCODE
+	void *codeaddr;
+#endif/*KNH_USING_THREADEDCODE*/
+	knh_opcode_t opcode;
+	knh_sfx_t a1;
+	knh_sfx_t a2;
+	void *nextaddr;
+} klr_xmovxb_t;
+
+#define OPSIZE_XMOVXB  (sizeof(klr_xmovxb_t)-sizeof(void*))
+
+#define OPCODE_SWAP ((knh_opcode_t)21)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -321,7 +447,7 @@ typedef struct {
 
 #define OPSIZE_SWAP  (sizeof(klr_swap_t)-sizeof(void*))
 
-#define OPCODE_PINIO ((knh_opcode_t)13)
+#define OPCODE_PINIO ((knh_opcode_t)22)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -334,7 +460,7 @@ typedef struct {
 
 #define OPSIZE_PINIO  (sizeof(klr_pinio_t)-sizeof(void*))
 
-#define OPCODE_SETESP ((knh_opcode_t)14)
+#define OPCODE_SETESP ((knh_opcode_t)23)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -346,7 +472,7 @@ typedef struct {
 
 #define OPSIZE_SETESP  (sizeof(klr_setesp_t)-sizeof(void*))
 
-#define OPCODE_CHECKESP ((knh_opcode_t)15)
+#define OPCODE_CHECKESP ((knh_opcode_t)24)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -358,7 +484,7 @@ typedef struct {
 
 #define OPSIZE_CHECKESP  (sizeof(klr_checkesp_t)-sizeof(void*))
 
-#define OPCODE_RET ((knh_opcode_t)16)
+#define OPCODE_RET ((knh_opcode_t)25)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -369,7 +495,7 @@ typedef struct {
 
 #define OPSIZE_RET  (sizeof(klr_ret_t)-sizeof(void*))
 
-#define OPCODE_RETN ((knh_opcode_t)17)
+#define OPCODE_RETN ((knh_opcode_t)26)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -382,7 +508,7 @@ typedef struct {
 
 #define OPSIZE_RETN  (sizeof(klr_retn_t)-sizeof(void*))
 
-#define OPCODE_RETA ((knh_opcode_t)18)
+#define OPCODE_RETA ((knh_opcode_t)27)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -395,7 +521,7 @@ typedef struct {
 
 #define OPSIZE_RETA  (sizeof(klr_reta_t)-sizeof(void*))
 
-#define OPCODE_RETO ((knh_opcode_t)19)
+#define OPCODE_RETO ((knh_opcode_t)28)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -408,7 +534,7 @@ typedef struct {
 
 #define OPSIZE_RETO  (sizeof(klr_reto_t)-sizeof(void*))
 
-#define OPCODE_RETX ((knh_opcode_t)20)
+#define OPCODE_RETX ((knh_opcode_t)29)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -421,7 +547,7 @@ typedef struct {
 
 #define OPSIZE_RETX  (sizeof(klr_retx_t)-sizeof(void*))
 
-#define OPCODE_BOX ((knh_opcode_t)21)
+#define OPCODE_BOX ((knh_opcode_t)30)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -434,7 +560,7 @@ typedef struct {
 
 #define OPSIZE_BOX  (sizeof(klr_box_t)-sizeof(void*))
 
-#define OPCODE_BOXNC ((knh_opcode_t)22)
+#define OPCODE_BOXNC ((knh_opcode_t)31)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -447,7 +573,7 @@ typedef struct {
 
 #define OPSIZE_BOXNC  (sizeof(klr_boxnc_t)-sizeof(void*))
 
-#define OPCODE_NNBOX ((knh_opcode_t)23)
+#define OPCODE_NNBOX ((knh_opcode_t)32)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -460,7 +586,7 @@ typedef struct {
 
 #define OPSIZE_NNBOX  (sizeof(klr_nnbox_t)-sizeof(void*))
 
-#define OPCODE_NNBOXNC ((knh_opcode_t)24)
+#define OPCODE_NNBOXNC ((knh_opcode_t)33)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -473,7 +599,7 @@ typedef struct {
 
 #define OPSIZE_NNBOXNC  (sizeof(klr_nnboxnc_t)-sizeof(void*))
 
-#define OPCODE_UNBOX ((knh_opcode_t)25)
+#define OPCODE_UNBOX ((knh_opcode_t)34)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -485,7 +611,7 @@ typedef struct {
 
 #define OPSIZE_UNBOX  (sizeof(klr_unbox_t)-sizeof(void*))
 
-#define OPCODE_ISNULL ((knh_opcode_t)26)
+#define OPCODE_ISNULL ((knh_opcode_t)35)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -497,7 +623,7 @@ typedef struct {
 
 #define OPSIZE_ISNULL  (sizeof(klr_isnull_t)-sizeof(void*))
 
-#define OPCODE_ISNULLX ((knh_opcode_t)27)
+#define OPCODE_ISNULLX ((knh_opcode_t)36)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -509,7 +635,7 @@ typedef struct {
 
 #define OPSIZE_ISNULLX  (sizeof(klr_isnullx_t)-sizeof(void*))
 
-#define OPCODE_ISTYPE ((knh_opcode_t)28)
+#define OPCODE_ISTYPE ((knh_opcode_t)37)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -522,7 +648,7 @@ typedef struct {
 
 #define OPSIZE_ISTYPE  (sizeof(klr_istype_t)-sizeof(void*))
 
-#define OPCODE_ISNNTYPE ((knh_opcode_t)29)
+#define OPCODE_ISNNTYPE ((knh_opcode_t)38)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -535,7 +661,7 @@ typedef struct {
 
 #define OPSIZE_ISNNTYPE  (sizeof(klr_isnntype_t)-sizeof(void*))
 
-#define OPCODE_FCALL ((knh_opcode_t)30)
+#define OPCODE_FCALL ((knh_opcode_t)39)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -550,7 +676,7 @@ typedef struct {
 
 #define OPSIZE_FCALL  (sizeof(klr_fcall_t)-sizeof(void*))
 
-#define OPCODE_SCALL ((knh_opcode_t)31)
+#define OPCODE_SCALL ((knh_opcode_t)40)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -564,7 +690,7 @@ typedef struct {
 
 #define OPSIZE_SCALL  (sizeof(klr_scall_t)-sizeof(void*))
 
-#define OPCODE_AINVOKE ((knh_opcode_t)32)
+#define OPCODE_AINVOKE ((knh_opcode_t)41)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -578,7 +704,7 @@ typedef struct {
 
 #define OPSIZE_AINVOKE  (sizeof(klr_ainvoke_t)-sizeof(void*))
 
-#define OPCODE_CALL ((knh_opcode_t)33)
+#define OPCODE_CALL ((knh_opcode_t)42)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -592,7 +718,7 @@ typedef struct {
 
 #define OPSIZE_CALL  (sizeof(klr_call_t)-sizeof(void*))
 
-#define OPCODE_ACALL ((knh_opcode_t)34)
+#define OPCODE_ACALL ((knh_opcode_t)43)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -606,7 +732,7 @@ typedef struct {
 
 #define OPSIZE_ACALL  (sizeof(klr_acall_t)-sizeof(void*))
 
-#define OPCODE_NEW ((knh_opcode_t)35)
+#define OPCODE_NEW ((knh_opcode_t)44)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -622,7 +748,7 @@ typedef struct {
 
 #define OPSIZE_NEW  (sizeof(klr_new_t)-sizeof(void*))
 
-#define OPCODE_TOSTR ((knh_opcode_t)36)
+#define OPCODE_TOSTR ((knh_opcode_t)45)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -635,7 +761,7 @@ typedef struct {
 
 #define OPSIZE_TOSTR  (sizeof(klr_tostr_t)-sizeof(void*))
 
-#define OPCODE_TOSTRF ((knh_opcode_t)37)
+#define OPCODE_TOSTRF ((knh_opcode_t)46)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -649,7 +775,7 @@ typedef struct {
 
 #define OPSIZE_TOSTRF  (sizeof(klr_tostrf_t)-sizeof(void*))
 
-#define OPCODE_SMAP ((knh_opcode_t)38)
+#define OPCODE_SMAP ((knh_opcode_t)47)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -662,7 +788,7 @@ typedef struct {
 
 #define OPSIZE_SMAP  (sizeof(klr_smap_t)-sizeof(void*))
 
-#define OPCODE_SMAPNC ((knh_opcode_t)39)
+#define OPCODE_SMAPNC ((knh_opcode_t)48)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -675,7 +801,7 @@ typedef struct {
 
 #define OPSIZE_SMAPNC  (sizeof(klr_smapnc_t)-sizeof(void*))
 
-#define OPCODE_MAP ((knh_opcode_t)40)
+#define OPCODE_MAP ((knh_opcode_t)49)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -688,7 +814,7 @@ typedef struct {
 
 #define OPSIZE_MAP  (sizeof(klr_map_t)-sizeof(void*))
 
-#define OPCODE_MAPNC ((knh_opcode_t)41)
+#define OPCODE_MAPNC ((knh_opcode_t)50)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -701,7 +827,7 @@ typedef struct {
 
 #define OPSIZE_MAPNC  (sizeof(klr_mapnc_t)-sizeof(void*))
 
-#define OPCODE_AMAP ((knh_opcode_t)42)
+#define OPCODE_AMAP ((knh_opcode_t)51)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -714,7 +840,7 @@ typedef struct {
 
 #define OPSIZE_AMAP  (sizeof(klr_amap_t)-sizeof(void*))
 
-#define OPCODE_NNMAP ((knh_opcode_t)43)
+#define OPCODE_NNMAP ((knh_opcode_t)52)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -727,7 +853,7 @@ typedef struct {
 
 #define OPSIZE_NNMAP  (sizeof(klr_nnmap_t)-sizeof(void*))
 
-#define OPCODE_JMP ((knh_opcode_t)44)
+#define OPCODE_JMP ((knh_opcode_t)53)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -745,7 +871,7 @@ typedef struct {
 
 #define OPSIZE_JMP  (sizeof(klr_jmp_t)-sizeof(void*))
 
-#define OPCODE_BJIFT ((knh_opcode_t)45)
+#define OPCODE_BJIFT ((knh_opcode_t)54)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -764,7 +890,7 @@ typedef struct {
 
 #define OPSIZE_BJIFT  (sizeof(klr_bjift_t)-sizeof(void*))
 
-#define OPCODE_BJIFF ((knh_opcode_t)46)
+#define OPCODE_BJIFF ((knh_opcode_t)55)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -783,7 +909,7 @@ typedef struct {
 
 #define OPSIZE_BJIFF  (sizeof(klr_bjiff_t)-sizeof(void*))
 
-#define OPCODE_BJIFF_LOOP ((knh_opcode_t)47)
+#define OPCODE_BJIFF_LOOP ((knh_opcode_t)56)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -802,7 +928,7 @@ typedef struct {
 
 #define OPSIZE_BJIFF_LOOP  (sizeof(klr_bjiff_loop_t)-sizeof(void*))
 
-#define OPCODE_JIFNUL ((knh_opcode_t)48)
+#define OPCODE_JIFNUL ((knh_opcode_t)57)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -821,7 +947,7 @@ typedef struct {
 
 #define OPSIZE_JIFNUL  (sizeof(klr_jifnul_t)-sizeof(void*))
 
-#define OPCODE_JIFNN ((knh_opcode_t)49)
+#define OPCODE_JIFNN ((knh_opcode_t)58)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -840,7 +966,7 @@ typedef struct {
 
 #define OPSIZE_JIFNN  (sizeof(klr_jifnn_t)-sizeof(void*))
 
-#define OPCODE_NEXT ((knh_opcode_t)50)
+#define OPCODE_NEXT ((knh_opcode_t)59)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -861,7 +987,7 @@ typedef struct {
 
 #define OPSIZE_NEXT  (sizeof(klr_next_t)-sizeof(void*))
 
-#define OPCODE_INEXT ((knh_opcode_t)51)
+#define OPCODE_INEXT ((knh_opcode_t)60)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -883,7 +1009,7 @@ typedef struct {
 
 #define OPSIZE_INEXT  (sizeof(klr_inext_t)-sizeof(void*))
 
-#define OPCODE_MAPNEXT ((knh_opcode_t)52)
+#define OPCODE_MAPNEXT ((knh_opcode_t)61)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -905,7 +1031,7 @@ typedef struct {
 
 #define OPSIZE_MAPNEXT  (sizeof(klr_mapnext_t)-sizeof(void*))
 
-#define OPCODE_SMAPNEXT ((knh_opcode_t)53)
+#define OPCODE_SMAPNEXT ((knh_opcode_t)62)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -927,7 +1053,7 @@ typedef struct {
 
 #define OPSIZE_SMAPNEXT  (sizeof(klr_smapnext_t)-sizeof(void*))
 
-#define OPCODE_TRY ((knh_opcode_t)54)
+#define OPCODE_TRY ((knh_opcode_t)63)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -946,7 +1072,7 @@ typedef struct {
 
 #define OPSIZE_TRY  (sizeof(klr_try_t)-sizeof(void*))
 
-#define OPCODE_TRYEND ((knh_opcode_t)55)
+#define OPCODE_TRYEND ((knh_opcode_t)64)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -958,7 +1084,7 @@ typedef struct {
 
 #define OPSIZE_TRYEND  (sizeof(klr_tryend_t)-sizeof(void*))
 
-#define OPCODE_CATCH ((knh_opcode_t)56)
+#define OPCODE_CATCH ((knh_opcode_t)65)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -979,7 +1105,7 @@ typedef struct {
 
 #define OPSIZE_CATCH  (sizeof(klr_catch_t)-sizeof(void*))
 
-#define OPCODE_THROW ((knh_opcode_t)57)
+#define OPCODE_THROW ((knh_opcode_t)66)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -991,7 +1117,7 @@ typedef struct {
 
 #define OPSIZE_THROW  (sizeof(klr_throw_t)-sizeof(void*))
 
-#define OPCODE_THROWS ((knh_opcode_t)58)
+#define OPCODE_THROWS ((knh_opcode_t)67)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1003,7 +1129,7 @@ typedef struct {
 
 #define OPSIZE_THROWS  (sizeof(klr_throws_t)-sizeof(void*))
 
-#define OPCODE_THROW_AGAIN ((knh_opcode_t)59)
+#define OPCODE_THROW_AGAIN ((knh_opcode_t)68)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1015,7 +1141,7 @@ typedef struct {
 
 #define OPSIZE_THROW_AGAIN  (sizeof(klr_throw_again_t)-sizeof(void*))
 
-#define OPCODE_P ((knh_opcode_t)60)
+#define OPCODE_P ((knh_opcode_t)69)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1029,7 +1155,7 @@ typedef struct {
 
 #define OPSIZE_P  (sizeof(klr_p_t)-sizeof(void*))
 
-#define OPCODE_PMSG ((knh_opcode_t)61)
+#define OPCODE_PMSG ((knh_opcode_t)70)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1042,7 +1168,7 @@ typedef struct {
 
 #define OPSIZE_PMSG  (sizeof(klr_pmsg_t)-sizeof(void*))
 
-#define OPCODE_ICAST ((knh_opcode_t)62)
+#define OPCODE_ICAST ((knh_opcode_t)71)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1054,7 +1180,7 @@ typedef struct {
 
 #define OPSIZE_ICAST  (sizeof(klr_icast_t)-sizeof(void*))
 
-#define OPCODE_INCAST ((knh_opcode_t)63)
+#define OPCODE_INCAST ((knh_opcode_t)72)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1066,7 +1192,7 @@ typedef struct {
 
 #define OPSIZE_INCAST  (sizeof(klr_incast_t)-sizeof(void*))
 
-#define OPCODE_FCAST ((knh_opcode_t)64)
+#define OPCODE_FCAST ((knh_opcode_t)73)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1078,7 +1204,7 @@ typedef struct {
 
 #define OPSIZE_FCAST  (sizeof(klr_fcast_t)-sizeof(void*))
 
-#define OPCODE_FNCAST ((knh_opcode_t)65)
+#define OPCODE_FNCAST ((knh_opcode_t)74)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1090,7 +1216,7 @@ typedef struct {
 
 #define OPSIZE_FNCAST  (sizeof(klr_fncast_t)-sizeof(void*))
 
-#define OPCODE_BNOT ((knh_opcode_t)66)
+#define OPCODE_BNOT ((knh_opcode_t)75)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1103,7 +1229,7 @@ typedef struct {
 
 #define OPSIZE_BNOT  (sizeof(klr_bnot_t)-sizeof(void*))
 
-#define OPCODE_INEG ((knh_opcode_t)67)
+#define OPCODE_INEG ((knh_opcode_t)76)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1116,7 +1242,7 @@ typedef struct {
 
 #define OPSIZE_INEG  (sizeof(klr_ineg_t)-sizeof(void*))
 
-#define OPCODE_IADD ((knh_opcode_t)68)
+#define OPCODE_IADD ((knh_opcode_t)77)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1130,7 +1256,7 @@ typedef struct {
 
 #define OPSIZE_IADD  (sizeof(klr_iadd_t)-sizeof(void*))
 
-#define OPCODE_IADDN ((knh_opcode_t)69)
+#define OPCODE_IADDN ((knh_opcode_t)78)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1144,7 +1270,7 @@ typedef struct {
 
 #define OPSIZE_IADDN  (sizeof(klr_iaddn_t)-sizeof(void*))
 
-#define OPCODE_ISUB ((knh_opcode_t)70)
+#define OPCODE_ISUB ((knh_opcode_t)79)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1158,7 +1284,7 @@ typedef struct {
 
 #define OPSIZE_ISUB  (sizeof(klr_isub_t)-sizeof(void*))
 
-#define OPCODE_ISUBN ((knh_opcode_t)71)
+#define OPCODE_ISUBN ((knh_opcode_t)80)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1172,7 +1298,7 @@ typedef struct {
 
 #define OPSIZE_ISUBN  (sizeof(klr_isubn_t)-sizeof(void*))
 
-#define OPCODE_IMUL ((knh_opcode_t)72)
+#define OPCODE_IMUL ((knh_opcode_t)81)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1186,7 +1312,7 @@ typedef struct {
 
 #define OPSIZE_IMUL  (sizeof(klr_imul_t)-sizeof(void*))
 
-#define OPCODE_IMULN ((knh_opcode_t)73)
+#define OPCODE_IMULN ((knh_opcode_t)82)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1200,7 +1326,7 @@ typedef struct {
 
 #define OPSIZE_IMULN  (sizeof(klr_imuln_t)-sizeof(void*))
 
-#define OPCODE_IDIV ((knh_opcode_t)74)
+#define OPCODE_IDIV ((knh_opcode_t)83)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1214,7 +1340,7 @@ typedef struct {
 
 #define OPSIZE_IDIV  (sizeof(klr_idiv_t)-sizeof(void*))
 
-#define OPCODE_IDIVN ((knh_opcode_t)75)
+#define OPCODE_IDIVN ((knh_opcode_t)84)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1228,7 +1354,7 @@ typedef struct {
 
 #define OPSIZE_IDIVN  (sizeof(klr_idivn_t)-sizeof(void*))
 
-#define OPCODE_IMOD ((knh_opcode_t)76)
+#define OPCODE_IMOD ((knh_opcode_t)85)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1242,7 +1368,7 @@ typedef struct {
 
 #define OPSIZE_IMOD  (sizeof(klr_imod_t)-sizeof(void*))
 
-#define OPCODE_IMODN ((knh_opcode_t)77)
+#define OPCODE_IMODN ((knh_opcode_t)86)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1256,7 +1382,7 @@ typedef struct {
 
 #define OPSIZE_IMODN  (sizeof(klr_imodn_t)-sizeof(void*))
 
-#define OPCODE_IEQ ((knh_opcode_t)78)
+#define OPCODE_IEQ ((knh_opcode_t)87)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1270,7 +1396,7 @@ typedef struct {
 
 #define OPSIZE_IEQ  (sizeof(klr_ieq_t)-sizeof(void*))
 
-#define OPCODE_IEQN ((knh_opcode_t)79)
+#define OPCODE_IEQN ((knh_opcode_t)88)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1284,7 +1410,7 @@ typedef struct {
 
 #define OPSIZE_IEQN  (sizeof(klr_ieqn_t)-sizeof(void*))
 
-#define OPCODE_INEQ ((knh_opcode_t)80)
+#define OPCODE_INEQ ((knh_opcode_t)89)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1298,7 +1424,7 @@ typedef struct {
 
 #define OPSIZE_INEQ  (sizeof(klr_ineq_t)-sizeof(void*))
 
-#define OPCODE_INEQN ((knh_opcode_t)81)
+#define OPCODE_INEQN ((knh_opcode_t)90)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1312,7 +1438,7 @@ typedef struct {
 
 #define OPSIZE_INEQN  (sizeof(klr_ineqn_t)-sizeof(void*))
 
-#define OPCODE_ILT ((knh_opcode_t)82)
+#define OPCODE_ILT ((knh_opcode_t)91)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1326,7 +1452,7 @@ typedef struct {
 
 #define OPSIZE_ILT  (sizeof(klr_ilt_t)-sizeof(void*))
 
-#define OPCODE_ILTN ((knh_opcode_t)83)
+#define OPCODE_ILTN ((knh_opcode_t)92)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1340,7 +1466,7 @@ typedef struct {
 
 #define OPSIZE_ILTN  (sizeof(klr_iltn_t)-sizeof(void*))
 
-#define OPCODE_ILTE ((knh_opcode_t)84)
+#define OPCODE_ILTE ((knh_opcode_t)93)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1354,7 +1480,7 @@ typedef struct {
 
 #define OPSIZE_ILTE  (sizeof(klr_ilte_t)-sizeof(void*))
 
-#define OPCODE_ILTEN ((knh_opcode_t)85)
+#define OPCODE_ILTEN ((knh_opcode_t)94)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1368,7 +1494,7 @@ typedef struct {
 
 #define OPSIZE_ILTEN  (sizeof(klr_ilten_t)-sizeof(void*))
 
-#define OPCODE_IGT ((knh_opcode_t)86)
+#define OPCODE_IGT ((knh_opcode_t)95)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1382,7 +1508,7 @@ typedef struct {
 
 #define OPSIZE_IGT  (sizeof(klr_igt_t)-sizeof(void*))
 
-#define OPCODE_IGTN ((knh_opcode_t)87)
+#define OPCODE_IGTN ((knh_opcode_t)96)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1396,7 +1522,7 @@ typedef struct {
 
 #define OPSIZE_IGTN  (sizeof(klr_igtn_t)-sizeof(void*))
 
-#define OPCODE_IGTE ((knh_opcode_t)88)
+#define OPCODE_IGTE ((knh_opcode_t)97)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1410,7 +1536,7 @@ typedef struct {
 
 #define OPSIZE_IGTE  (sizeof(klr_igte_t)-sizeof(void*))
 
-#define OPCODE_IGTEN ((knh_opcode_t)89)
+#define OPCODE_IGTEN ((knh_opcode_t)98)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1424,7 +1550,7 @@ typedef struct {
 
 #define OPSIZE_IGTEN  (sizeof(klr_igten_t)-sizeof(void*))
 
-#define OPCODE_FNEG ((knh_opcode_t)90)
+#define OPCODE_FNEG ((knh_opcode_t)99)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1437,7 +1563,7 @@ typedef struct {
 
 #define OPSIZE_FNEG  (sizeof(klr_fneg_t)-sizeof(void*))
 
-#define OPCODE_FADD ((knh_opcode_t)91)
+#define OPCODE_FADD ((knh_opcode_t)100)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1451,7 +1577,7 @@ typedef struct {
 
 #define OPSIZE_FADD  (sizeof(klr_fadd_t)-sizeof(void*))
 
-#define OPCODE_FADDN ((knh_opcode_t)92)
+#define OPCODE_FADDN ((knh_opcode_t)101)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1465,7 +1591,7 @@ typedef struct {
 
 #define OPSIZE_FADDN  (sizeof(klr_faddn_t)-sizeof(void*))
 
-#define OPCODE_FSUB ((knh_opcode_t)93)
+#define OPCODE_FSUB ((knh_opcode_t)102)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1479,7 +1605,7 @@ typedef struct {
 
 #define OPSIZE_FSUB  (sizeof(klr_fsub_t)-sizeof(void*))
 
-#define OPCODE_FSUBN ((knh_opcode_t)94)
+#define OPCODE_FSUBN ((knh_opcode_t)103)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1493,7 +1619,7 @@ typedef struct {
 
 #define OPSIZE_FSUBN  (sizeof(klr_fsubn_t)-sizeof(void*))
 
-#define OPCODE_FMUL ((knh_opcode_t)95)
+#define OPCODE_FMUL ((knh_opcode_t)104)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1507,7 +1633,7 @@ typedef struct {
 
 #define OPSIZE_FMUL  (sizeof(klr_fmul_t)-sizeof(void*))
 
-#define OPCODE_FMULN ((knh_opcode_t)96)
+#define OPCODE_FMULN ((knh_opcode_t)105)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1521,7 +1647,7 @@ typedef struct {
 
 #define OPSIZE_FMULN  (sizeof(klr_fmuln_t)-sizeof(void*))
 
-#define OPCODE_FDIV ((knh_opcode_t)97)
+#define OPCODE_FDIV ((knh_opcode_t)106)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1535,7 +1661,7 @@ typedef struct {
 
 #define OPSIZE_FDIV  (sizeof(klr_fdiv_t)-sizeof(void*))
 
-#define OPCODE_FDIVN ((knh_opcode_t)98)
+#define OPCODE_FDIVN ((knh_opcode_t)107)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1549,7 +1675,7 @@ typedef struct {
 
 #define OPSIZE_FDIVN  (sizeof(klr_fdivn_t)-sizeof(void*))
 
-#define OPCODE_FEQ ((knh_opcode_t)99)
+#define OPCODE_FEQ ((knh_opcode_t)108)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1563,7 +1689,7 @@ typedef struct {
 
 #define OPSIZE_FEQ  (sizeof(klr_feq_t)-sizeof(void*))
 
-#define OPCODE_FEQN ((knh_opcode_t)100)
+#define OPCODE_FEQN ((knh_opcode_t)109)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1577,7 +1703,7 @@ typedef struct {
 
 #define OPSIZE_FEQN  (sizeof(klr_feqn_t)-sizeof(void*))
 
-#define OPCODE_FNEQ ((knh_opcode_t)101)
+#define OPCODE_FNEQ ((knh_opcode_t)110)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1591,7 +1717,7 @@ typedef struct {
 
 #define OPSIZE_FNEQ  (sizeof(klr_fneq_t)-sizeof(void*))
 
-#define OPCODE_FNEQN ((knh_opcode_t)102)
+#define OPCODE_FNEQN ((knh_opcode_t)111)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1605,7 +1731,7 @@ typedef struct {
 
 #define OPSIZE_FNEQN  (sizeof(klr_fneqn_t)-sizeof(void*))
 
-#define OPCODE_FLT ((knh_opcode_t)103)
+#define OPCODE_FLT ((knh_opcode_t)112)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1619,7 +1745,7 @@ typedef struct {
 
 #define OPSIZE_FLT  (sizeof(klr_flt_t)-sizeof(void*))
 
-#define OPCODE_FLTN ((knh_opcode_t)104)
+#define OPCODE_FLTN ((knh_opcode_t)113)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1633,7 +1759,7 @@ typedef struct {
 
 #define OPSIZE_FLTN  (sizeof(klr_fltn_t)-sizeof(void*))
 
-#define OPCODE_FLTE ((knh_opcode_t)105)
+#define OPCODE_FLTE ((knh_opcode_t)114)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1647,7 +1773,7 @@ typedef struct {
 
 #define OPSIZE_FLTE  (sizeof(klr_flte_t)-sizeof(void*))
 
-#define OPCODE_FLTEN ((knh_opcode_t)106)
+#define OPCODE_FLTEN ((knh_opcode_t)115)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1661,7 +1787,7 @@ typedef struct {
 
 #define OPSIZE_FLTEN  (sizeof(klr_flten_t)-sizeof(void*))
 
-#define OPCODE_FGT ((knh_opcode_t)107)
+#define OPCODE_FGT ((knh_opcode_t)116)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1675,7 +1801,7 @@ typedef struct {
 
 #define OPSIZE_FGT  (sizeof(klr_fgt_t)-sizeof(void*))
 
-#define OPCODE_FGTN ((knh_opcode_t)108)
+#define OPCODE_FGTN ((knh_opcode_t)117)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1689,7 +1815,7 @@ typedef struct {
 
 #define OPSIZE_FGTN  (sizeof(klr_fgtn_t)-sizeof(void*))
 
-#define OPCODE_FGTE ((knh_opcode_t)109)
+#define OPCODE_FGTE ((knh_opcode_t)118)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1703,7 +1829,7 @@ typedef struct {
 
 #define OPSIZE_FGTE  (sizeof(klr_fgte_t)-sizeof(void*))
 
-#define OPCODE_FGTEN ((knh_opcode_t)110)
+#define OPCODE_FGTEN ((knh_opcode_t)119)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1717,7 +1843,7 @@ typedef struct {
 
 #define OPSIZE_FGTEN  (sizeof(klr_fgten_t)-sizeof(void*))
 
-#define OPCODE_INITCODE ((knh_opcode_t)111)
+#define OPCODE_INITCODE ((knh_opcode_t)120)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
@@ -1729,7 +1855,7 @@ typedef struct {
 
 #define OPSIZE_INITCODE  (sizeof(klr_initcode_t)-sizeof(void*))
 
-#define OPCODE_NOP ((knh_opcode_t)112)
+#define OPCODE_NOP ((knh_opcode_t)121)
 typedef struct {
 #ifdef KNH_USING_THREADEDCODE
 	void *codeaddr;
