@@ -302,7 +302,7 @@ String* knh_ResultSet_getString(Ctx *ctx, ResultSet *o, size_t n)
 	case knh_ResultSet_CTYPE__null :
 		return (String*)KNH_NULL;
 	case knh_ResultSet_CTYPE__integer :
-		return new_String__integer(ctx, (knh_int_t)(*((knh_int_t*)p)));
+		return new_String__int(ctx, (knh_int_t)(*((knh_int_t*)p)));
 	case knh_ResultSet_CTYPE__float :
 		return new_String__float(ctx, (knh_float_t)(*((knh_float_t*)p)));
 	case knh_ResultSet_CTYPE__text :
