@@ -412,6 +412,7 @@ static
 void KNH_ASM_BOX(Ctx *ctx, Asm *abr, knh_type_t atype, int a)
 {
 	if(knh_rtti_issync(abr, a)) return;
+	DBG2_P("@@@ atype=%s%s", TYPEQN(atype));
 	knh_class_t cid = CLASS_type(atype);
 	KNH_ASSERT_cid(cid);
 	knh_class_t bcid = ctx->share->ClassTable[cid].bcid;
@@ -435,7 +436,6 @@ void KNH_ASM_NNBOX(Ctx *ctx, Asm *abr, knh_type_t atype, int a)
 	knh_class_t cid = CLASS_type(atype);
 	KNH_ASSERT_cid(cid);
 	knh_class_t bcid = ctx->share->ClassTable[cid].bcid;
-	//DBG2_P("atype=%s%s", TYPEQN(atype));
 	if(bcid == CLASS_Boolean || bcid == CLASS_Int || bcid == CLASS_Float) {
 		if(IS_NNTYPE(atype)) {
 			KNH_ASM_NNBOX_(ctx, abr, a, cid);
@@ -448,16 +448,6 @@ void KNH_ASM_NNBOX(Ctx *ctx, Asm *abr, knh_type_t atype, int a)
 
 /* ------------------------------------------------------------------------ */
 
-//static
-//void KNH_ASM_UNBOX(Ctx *ctx, Asm *abr, knh_type_t atype, int a)
-//{
-//	if(knh_rtti_issync(abr, a)) return;
-//	KNH_ASM_UNBOX_(ctx, abr, a);
-//	knh_rtti_sync(abr, a);
-//}
-
-/* ------------------------------------------------------------------------ */
-
 static
 void KNH_ASM_SMOVx(Ctx *ctx, Asm *abr, knh_type_t atype, int a, knh_type_t btype, knh_sfx_t bx)
 {
@@ -727,20 +717,6 @@ void KNH_ASM_RET(Ctx *ctx, Asm *abr)
 }
 
 
-/* ------------------------------------------------------------------------ */
-
-//static
-//knh_methodn_t knh_asm_getmn(Ctx *ctx, Asm *o, Token *tk)
-//{
-//	if(SP(tk)->tt == TT_MN) {
-//		return (knh_methodn_t)DP(tk)->index;
-//	}
-//	if(IS_Method(DP(tk)->data)) {
-//		return DP(DP(tk)->mtd)->mn;
-//	}
-//	return METHODN_NONAME;
-//}
-
 /* ------------------------------------------------------------------------ */
 
 static
@@ -2125,11 +2101,13 @@ void knh_StmtRETURN_asm(Ctx *ctx, Stmt *stmt, Asm *abr)
 static
 void knh_StmtERR_asm(Ctx *ctx, Stmt *stmt, Asm *abr)
 {
-	DBG2_P("****************ERROR************************");
-	KNH_ASSERT(IS_bString(DP(stmt)->errMsg));
-	if(IS_bString(DP(stmt)->errMsg)) {
-		KNH_ASM_THROWs_(ctx, abr, (Object*)DP(stmt)->errMsg);
+	if(!IS_bString(DP(stmt)->errMsg)) {
+		char buf[512];
+		knh_snprintf(buf, sizeof(buf), "Script!!: running errors at %s:%d", FILEIDN(SP(stmt)->fileid), SP(stmt)->line);
+		KNH_SETv(ctx, DP(stmt)->errMsg, new_String(ctx, B(buf), NULL));
+		KNH_SETv(ctx, DP(stmt)->next, KNH_NULL);
 	}
+	KNH_ASM_THROWs_(ctx, abr, (Object*)DP(stmt)->errMsg);
 }
 
 /* ======================================================================== */
@@ -2158,7 +2136,7 @@ String *knh_Term_getNameNULL(Term *tm)
 		return NULL;
 	}
 	else if(SP(tk)->tt == TT_NAME) {
-		DEBUG3_ASSERT(IS_String(DP(tk)->data));
+		DBG2_ASSERT(IS_String(DP(tk)->data));
 		return (String*)DP(tk)->data;
 	}
 	return NULL;
