@@ -137,14 +137,6 @@ void knh_class_addInterface(Ctx *ctx, knh_class_t cid, knh_class_t icid)
 	}
 }
 
-///* ------------------------------------------------------------------------ */
-//
-//static
-//Object *knh_ClassTable_fdefault__OBJECT(Ctx *ctx, knh_class_t cid)
-//{
-//	return new_Object_init(ctx, ctx->share->ClassTable[cid].oflag, cid, 0);
-//}
-
 /* ------------------------------------------------------------------------ */
 
 static
@@ -227,12 +219,36 @@ int knh_StmtCLASS_decl(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 	if(SP(StmtCLASS_instmt(stmt))->stt == STT_DONE) {
 		knh_Stmt_done(ctx, stmt);
 	}
+	KNH_NOTICE(ctx, "added new class: %s", CLASSN(cid));
 	return 1;
 }
 
 /* ------------------------------------------------------------------------ */
 /* [declc] */
 
+static
+char *knh_lookup_includeScript(Ctx *ctx, knh_bytes_t path, char *buf, size_t bufsiz)
+{
+	knh_index_t loc = knh_bytes_rindex(path, '/');
+	if(loc == -1) loc = knh_bytes_rindex(path, '\\');
+	char *filename = (char*)path.buf + loc + 1;
+
+#ifdef KNH_PREFIX
+	knh_snprintf(buf, bufsiz, "%s/lib/konoha/%s", KNH_PREFIX, filename);
+#else
+	knh_snprintf(buf, bufsiz, "%s/include/%s", knh_String_tochar(DP(ctx->sys)->homeDir), filename);
+#endif
+	if(knh_isfile(ctx, B(buf))) return buf;
+	char *p = knh_getenv("HOME");
+	if(p != NULL) {
+		knh_snprintf(buf, bufsiz, "%s/.konoha/%s", p, filename);
+		if(knh_isfile(ctx, B(buf))) return buf;
+	}
+	return NULL;
+}
+
+/* ------------------------------------------------------------------------ */
+
 static
 int knh_StmtIMPORT_decl(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 {
@@ -248,8 +264,11 @@ int knh_StmtIMPORT_decl(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 		bufp[0]=0;
 	}
 	knh_format_catpath(buff, sizeof(buff), B(bufp), knh_String_tobytes(fname));
-
-	knh_NameSpace_load(ctx, ns, B(buff), 1 /* isEval */);
+	if(!knh_isfile(ctx, B(buff))) {
+		knh_lookup_includeScript(ctx, knh_String_tobytes(fname), buff, sizeof(buff));
+	}
+	KNH_NOTICE(ctx, "including script: %s", buff);
+	knh_NameSpace_loadScript(ctx, ns, B(buff), 1 /* isEval */);
 	return 1;
 }
 
@@ -706,21 +725,22 @@ void knh_Asm_openlib(Ctx *ctx, Asm *abr, knh_bytes_t fpath)
 	}
 
 	knh_bytes_t f = knh_cwb_tobytes(cwb);
-	DBG2_P("opening lib .. '%s'", f.buf);
 	DP(abr)->dlhdr =knh_dlopen(ctx, (char*)f.buf, KNH_RTLD_LAZY);
 	if(DP(abr)->dlhdr != NULL) {
+		KNH_NOTICE(ctx, "opened dynamic library: %s", f.buf);
 		knh_finit finit = (knh_finit)knh_dlsym(ctx, DP(abr)->dlhdr, "init");
 		if(finit != NULL) {
 			finit(ctx);
 		}
 	}
 	else {
-		DBG2_P("cannot openlib .. '%s'", f.buf);
+		if(knh_isfile(ctx, f)) {
+			KNH_WARNING(ctx, "cannot open dynamic library: %s", f.buf);
+		}
 	}
 	knh_cwb_clear(cwb);
 }
 
-
 /* ======================================================================== */
 /* [loaded] */
 
@@ -751,7 +771,7 @@ int knh_NameSpace_isLoaded(Ctx *ctx, NameSpace *o, knh_fileid_t fileid)
 
 /* ------------------------------------------------------------------------ */
 
-int knh_NameSpace_load(Ctx *ctx, NameSpace *ns, knh_bytes_t fpath, int isEval)
+int knh_NameSpace_loadScript(Ctx *ctx, NameSpace *ns, knh_bytes_t fpath, int isEval)
 {
 	knh_fileid_t fileid = konoha_getFileId(ctx, fpath);
 	if(knh_NameSpace_isLoaded(ctx, ns, fileid)) {
@@ -783,7 +803,7 @@ void konoha_compile(Ctx *ctx, String *nsname, knh_bytes_t fpath)
 	KNH_TRY(ctx, L_CATCH, lsfp, 0);
 	{
 		NameSpace *ns = knh_Context_setNameSpace(ctx, nsname);
-		knh_NameSpace_load(ctx, ns, fpath, 0);
+		knh_NameSpace_loadScript(ctx, ns, fpath, 0);
 	}
 	KNH_LOCALBACK(ctx, lsfp);
 	return;
