@@ -484,7 +484,9 @@ int knh_Token_toClosureType(Ctx *ctx, Token *tkt, Token *tkp)
 		return 1;
 	}
 	if(tc.e == 0) {
-		knh_write(ctx, cwb.w, STEXT("void"));
+		knh_cwb_clear(cwb);
+		return 0;
+		//knh_write(ctx, cwb.w, STEXT("void"));
 	}
 	knh_putc(ctx, cwb.w, ')');
 	KNH_SETv(ctx, DP(tkt)->data, new_String__cwb(ctx, cwb));
