@@ -64,7 +64,7 @@ knh_fieldn_t knh_Token_getfnq(Ctx *ctx, Token *o)
 static
 knh_methodn_t knh_Token_getmn(Ctx *ctx, Token *o)
 {
-	DEBUG3_ASSERT(IS_Token(o));
+	DBG2_ASSERT(IS_Token(o));
 	if(SP(o)->tt == TT_MN) {
 		return DP(o)->mn;
 	}
@@ -157,7 +157,7 @@ knh_type_t knh_Token_gettype(Ctx *ctx, Token *o, NameSpace *ns, knh_class_t defc
 static
 knh_class_t knh_Token_getcid(Ctx *ctx, Token *o, NameSpace *ns, knh_class_t defc)
 {
-	DEBUG3_ASSERT(IS_Token(o));
+	DBG2_ASSERT(IS_Token(o));
 	if(SP(o)->tt == TT_CID) {
 		return DP(o)->cid;
 	}
@@ -497,6 +497,7 @@ int knh_Asm_globalIndex(Ctx *ctx, Asm *abr)
 static int knh_TokenNAME_typing(Ctx *ctx, Token *tk, Asm *abr)
 {
 	knh_fieldn_t fnq = knh_Token_getfnq(ctx, tk);
+	knh_index_t idx;
 	if(fnq == FIELDN_NONAME) {
 		goto L_ERROR;
 	}
@@ -504,7 +505,8 @@ static int knh_TokenNAME_typing(Ctx *ctx, Token *tk, Asm *abr)
 	if(FIELDN_IS_U1(fnq) || FIELDN_IS_SUPER(fnq)) goto L_FIELD;  /* _name */
 	if(FIELDN_IS_U2(fnq)) goto L_GLOBAL; /* __name */
 
-	knh_index_t idx = knh_Asm_indexOfVariable(abr, FIELDN_UNMASK(fnq));
+
+	idx = knh_Asm_indexOfVariable(abr, FIELDN_UNMASK(fnq));
 	if(idx != -1) {
 		knh_cfield_t *cf = knh_Asm_cfieldOfVariable(abr, idx);
 		knh_type_t type = knh_pmztype_totype(ctx, cf->type, DP(abr)->this_cid);
@@ -1024,14 +1026,14 @@ void TERMs_perrorTYPE(Ctx *ctx, Stmt *stmt, size_t n, int pe, knh_type_t reqt)
 	case STT_NEW:
 		{
 			Method *mtd = DP(DP(stmt)->tokens[0])->mtd;
-			DEBUG3_ASSERT(IS_Method(mtd));
+			DBG2_ASSERT(IS_Method(mtd));
 			knh_format_mtdparam(ctx, buf, sizeof(buf), mtd, n - 1);
 		}
 		break;
 	case STT_OP:
 		{
 			Method *mtd = DP(DP(stmt)->tokens[0])->mtd;
-			DEBUG3_ASSERT(IS_Method(mtd));
+			DBG2_ASSERT(IS_Method(mtd));
 			knh_format_op(ctx, buf, sizeof(buf), DP(mtd)->mn, n - 1);
 		}
 	case STT_LET:
@@ -1112,7 +1114,7 @@ Object *knh_StmtDECL_value(Ctx *ctx, knh_type_t type)
 
 static void knh_StmtDECL_toLET(Ctx *ctx, Stmt *stmt)
 {
-	DEBUG3_ASSERT(SP(stmt)->stt == STT_DECL);
+	DBG2_ASSERT(SP(stmt)->stt == STT_DECL);
 	SP(stmt)->stt = STT_LET;
 	KNH_SETv(ctx, DP(stmt)->terms[0], DP(stmt)->terms[1]);
 	KNH_SETv(ctx, DP(stmt)->terms[1], DP(stmt)->terms[2]);
@@ -1231,28 +1233,13 @@ int TERMs_isCONSTNAME(Ctx *ctx, Stmt *stmt, size_t n, Asm *abr, NameSpace *ns)
 
 /* ------------------------------------------------------------------------ */
 
-static
-int konoha_addClassConst(Ctx *ctx, knh_class_t cid, knh_bytes_t name, Object *value)
-{
-	KNH_ASSERT_cid(cid);
-	char bufcn[CLASSNAME_BUFSIZ];
-	knh_snprintf(bufcn, sizeof(bufcn), "%s.%s", CLASSN(cid), (char*)name.buf);
-	name = B(bufcn);
-	if(konoha_existsConst(ctx, name)) {
-		return 0;
-	}
-	konoha_addConst(ctx, new_String(ctx, name, NULL), value);
-	return 1;
-}
-
-/* ------------------------------------------------------------------------ */
-
 static
 Term *knh_StmtLET_declCONST(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns, int level)
 {
 	Token *tk = DP(stmt)->tokens[0];
 	knh_bytes_t cn = knh_Token_tobytes(ctx, tk);
 	int pe = KMSG_ESYNTAX;
+
 	if(level > 1) {
 		pe = KMSG_NOTHERE; goto L_PERROR;
 	}
@@ -1265,39 +1252,41 @@ Term *knh_StmtLET_declCONST(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns, int l
 		pe = KMSG_NNCONST; goto L_PERROR;
 	}
 
-	Object *value = TERMs_const(stmt, 1);
-	knh_index_t dotidx = knh_bytes_index(cn, '.');
+	{
+		Object *value = TERMs_const(stmt, 1);
+		knh_index_t dotidx = knh_bytes_index(cn, '.');
 
-	if(level == 0) {
-		if(dotidx == -1) {
-			if(knh_NameSpace_existsConst(ctx, ns, cn)) {
-				pe = KMSG_DUPCONST; goto L_PERROR;
+		if(level == 0) {
+			if(dotidx == -1) {
+				if(knh_NameSpace_existsConst(ctx, ns, cn)) {
+					pe = KMSG_DUPCONST; goto L_PERROR;
+				}
+				KNH_ASSERT(IS_String(DP(tk)->text));
+				knh_NameSpace_addConst(ctx, ns, DP(tk)->text, value);
+			}
+			else {
+				knh_bytes_t fn = knh_bytes_first(cn, dotidx);
+				knh_class_t cid = knh_NameSpace_geClassTable(ctx, ns, fn);
+				if(cid == CLASS_unknown) {
+					pe = KMSG_UCLASSN; goto L_PERROR;
+				}
+				if(!konoha_addClassConst(ctx, cid, new_String(ctx, knh_bytes_last(cn, dotidx+1), NULL), value)) {
+					pe = KMSG_DUPCONST; goto L_PERROR;
+				}
 			}
-			KNH_ASSERT(IS_String(DP(tk)->text));
-			knh_NameSpace_addConst(ctx, ns, DP(tk)->text, value);
 		}
-		else {
-			knh_bytes_t fn = knh_bytes_first(cn, dotidx);
-			knh_class_t cid = knh_NameSpace_geClassTable(ctx, ns, fn);
-			if(cid == CLASS_unknown) {
-				pe = KMSG_UCLASSN; goto L_PERROR;
+		else if(level == 1) {
+			knh_class_t cid = DP(abr)->this_cid;
+			if(dotidx != -1) {
+				pe = KMSG_NOTHERE; goto L_PERROR;
 			}
-			if(!konoha_addClassConst(ctx, cid, knh_bytes_last(cn, dotidx+1), value)) {
+			if(!konoha_addClassConst(ctx, cid, new_String(ctx, knh_bytes_last(cn, dotidx+1), NULL), value)) {
 				pe = KMSG_DUPCONST; goto L_PERROR;
 			}
 		}
+		knh_Stmt_done(ctx, stmt);
+		return TM(stmt);
 	}
-	else if(level == 1) {
-		knh_class_t cid = DP(abr)->this_cid;
-		if(dotidx != -1) {
-			pe = KMSG_NOTHERE; goto L_PERROR;
-		}
-		if(!konoha_addClassConst(ctx, cid, knh_bytes_last(cn, dotidx+1), value)) {
-			pe = KMSG_DUPCONST; goto L_PERROR;
-		}
-	}
-	knh_Stmt_done(ctx, stmt);
-	return TM(stmt);
 
 	L_PERROR:
 	knh_Token_perror(ctx, tk, pe);
@@ -1406,10 +1395,14 @@ Term *knh_StmtLET_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns, knh_type
 static
 Term *knh_StmtCALL1_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns, knh_type_t reqt)
 {
-	DEBUG3_ASSERT(DP(stmt)->size == 1);
+	DBG2_ASSERT(DP(stmt)->size == 1);
 	if(reqt == TYPE_void) {
-		TERMs_typing(ctx, stmt, 0, abr, ns, TYPE_Any, TWARN_);
-		knh_Stmt_setType(ctx, stmt, TERMs_gettype(stmt, 0));
+		if(TERMs_typing(ctx, stmt, 0, abr, ns, TYPE_Any, TWARN_)) {
+			knh_Stmt_setType(ctx, stmt, TERMs_gettype(stmt, 0));
+		}
+		else {
+			knh_Stmt_done(ctx, stmt);
+		}
 		return TM(stmt);
 	}
 	else {
@@ -1557,33 +1550,37 @@ static int knh_TokenNAME_isClosure(Ctx *ctx, Token *tk, Asm *abr)
 	if(FIELDN_IS_U1(fnq) || FIELDN_IS_SUPER(fnq)) goto L_FIELD;  /* _name */
 	if(FIELDN_IS_U2(fnq)) goto L_GLOBAL; /* __name */
 
-	knh_index_t idx = knh_Asm_indexOfVariable(abr, FIELDN_UNMASK(fnq));
-	if(idx != -1) {
-		knh_cfield_t *cf = knh_Asm_cfieldOfVariable(abr, idx);
-		knh_type_t type = knh_pmztype_totype(ctx, cf->type, DP(abr)->this_cid);
-		if(knh_type_isClosure(ctx, type)) {
-			knh_Token_toSTACK(ctx, tk, idx, type);
-			return 1;
+	{
+		knh_index_t idx = knh_Asm_indexOfVariable(abr, FIELDN_UNMASK(fnq));
+		if(idx != -1) {
+			knh_cfield_t *cf = knh_Asm_cfieldOfVariable(abr, idx);
+			knh_type_t type = knh_pmztype_totype(ctx, cf->type, DP(abr)->this_cid);
+			if(knh_type_isClosure(ctx, type)) {
+				knh_Token_toSTACK(ctx, tk, idx, type);
+				return 1;
+			}
+			return 0;
 		}
-		return 0;
 	}
 
 	L_FIELD:;
-	idx = knh_Class_queryField(ctx, DP(abr)->this_cid, fnq);
-	if(idx != -1) {
-		knh_cfield_t *cf = knh_Class_fieldAt(ctx, DP(abr)->this_cid, idx);
-		knh_type_t type = knh_pmztype_totype(ctx, cf->type, DP(abr)->this_cid);
-		if(knh_type_isClosure(ctx, type)) {
-			knh_Token_toFIELD(ctx, tk, idx, type);
-			return 1;
+	{
+		knh_index_t idx = knh_Class_queryField(ctx, DP(abr)->this_cid, fnq);
+		if(idx != -1) {
+			knh_cfield_t *cf = knh_Class_fieldAt(ctx, DP(abr)->this_cid, idx);
+			knh_type_t type = knh_pmztype_totype(ctx, cf->type, DP(abr)->this_cid);
+			if(knh_type_isClosure(ctx, type)) {
+				knh_Token_toFIELD(ctx, tk, idx, type);
+				return 1;
+			}
+			return 0;
 		}
-		return 0;
 	}
 
 	L_GLOBAL:;
 	{
 		Script *scr = knh_Asm_getScript(ctx, abr);
-		idx = knh_Class_queryField(ctx, knh_Object_cid(scr), fnq);
+		knh_index_t idx = knh_Class_queryField(ctx, knh_Object_cid(scr), fnq);
 		if(idx != -1) {
 			knh_cfield_t *cf = knh_Class_fieldAt(ctx, knh_Object_cid(scr), idx);
 			knh_type_t type = knh_pmztype_totype(ctx, cf->type, knh_Object_cid(scr));
@@ -1839,7 +1836,7 @@ Term *knh_StmtCALLBASE_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns, knh
 static
 Term *knh_StmtCALL_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns, knh_class_t reqt)
 {
-	DEBUG3_ASSERT(DP(stmt)->size > 1);
+	DBG2_ASSERT(DP(stmt)->size > 1);
 	knh_methodn_t mn = knh_Token_getmn(ctx, DP(stmt)->tokens[0]);
 	Term *tm = knh_StmtCALLBASE_typing(ctx, stmt, abr, ns, mn);
 	if(tm == NULL || IS_Token(tm) || knh_Stmt_isTyped(stmt)) {
@@ -1886,7 +1883,7 @@ Term *knh_StmtCALL_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns, knh_cla
 static
 Term *knh_StmtNEW_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns, knh_class_t reqt)
 {
-	DEBUG3_ASSERT(DP(stmt)->size > 1);
+	DBG2_ASSERT(DP(stmt)->size > 1);
 	knh_methodn_t mn = knh_Token_getmn(ctx, DP(stmt)->tokens[0]);
 
 	knh_class_t mtd_cid = knh_Token_getcid(ctx, DP(stmt)->tokens[1], ns, CLASS_unknown);
@@ -2056,7 +2053,7 @@ int knh_Stmt_checkOPSIZE(Ctx *ctx,Stmt *stmt, size_t n)
 static
 Term *knh_StmtOP_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns, knh_type_t reqt)
 {
-	DEBUG3_ASSERT(DP(stmt)->size > 1);
+	DBG2_ASSERT(DP(stmt)->size > 1);
 	size_t opsize = DP(stmt)->size - 1;
 	Token *optk = DP(stmt)->tokens[0];
 	knh_methodn_t mn = knh_token_tomethodn(SP(optk)->tt);
@@ -2228,7 +2225,7 @@ void knh_Token_toMPR(Ctx *ctx, Token *tk, knh_class_t cid, Mapper *mpr)
 static
 Term *knh_StmtMAPCAST_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns, knh_type_t reqt)
 {
-	DEBUG3_ASSERT(DP(stmt)->size > 1);
+	DBG2_ASSERT(DP(stmt)->size > 1);
 	if(!TERMs_typing(ctx, stmt, 0, abr, ns, TYPE_Any, TWARN_)) {
 		return NULL;
 	}
@@ -2302,7 +2299,7 @@ Term *knh_StmtMAPCAST_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns, knh_
 static
 Term *knh_StmtMT_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns, knh_type_t reqt)
 {
-	DEBUG3_ASSERT(DP(stmt)->size > 1);
+	DBG2_ASSERT(DP(stmt)->size > 1);
 	Token *tk = DP(stmt)->tokens[0];
 	knh_methodn_t mn = knh_Token_getmn(ctx, tk);
 	if(!TERMs_typing(ctx, stmt, 1, abr, ns, CLASS_Any, TCHECK_)) {
@@ -2359,7 +2356,7 @@ Term *knh_StmtOR_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns, knh_type_
 static
 Term *knh_StmtALT_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns, knh_type_t reqt)
 {
-	DEBUG3_ASSERT(DP(stmt)->size > 1);
+	DBG2_ASSERT(DP(stmt)->size > 1);
 	size_t i;
 	knh_class_t reqc = CLASS_type(reqt);
 	for(i = 0; i < DP(stmt)->size; i++) {
@@ -2382,7 +2379,7 @@ Term *knh_StmtALT_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns, knh_type
 static
 Term *knh_StmtTRI_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns, knh_type_t reqt)
 {
-	DEBUG3_ASSERT(DP(stmt)->size == 3);
+	DBG2_ASSERT(DP(stmt)->size == 3);
 	int res = 1;
 	if(!TERMs_typing(ctx, stmt, 0, abr, ns, NNTYPE_Boolean, TCHECK_)) res = 0;
 	if(!TERMs_typing(ctx, stmt, 1, abr, ns, reqt, TCHECK_)) res = 0;
@@ -2690,6 +2687,7 @@ Term *knh_StmtFOREACH_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 {
 	knh_type_t type = TYPE_Any;
 	knh_fieldn_t fn = knh_Token_getfnq(ctx, StmtFOREACH_name(stmt));
+	knh_class_t itrcid = CLASS_unknown;
 	if(TERMs_isASIS(stmt, FOREACH_type)) {  /* foreach(n in itr) */
 		knh_index_t idx = knh_Asm_indexOfVariable(abr, fn);
 		if(idx == -1) { //DEBUG3("type inferencing..");
@@ -2706,7 +2704,7 @@ Term *knh_StmtFOREACH_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 					return NULL;
 				}
 			}
-			knh_class_t itrcid = TERMs_getcid(stmt, FOREACH_iter);
+			itrcid = TERMs_getcid(stmt, FOREACH_iter);
 			type = NNTYPE_cid(ctx->share->ClassTable[itrcid].p1);
 			type = knh_Asm_typeinfer(ctx, abr, type, FIELDN(fn));
 			knh_Asm_declareVariable(ctx, abr, 0, type, fn, konoha_geClassTableDefaultValue(ctx, CLASS_type(type)));
@@ -2728,7 +2726,7 @@ Term *knh_StmtFOREACH_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 	if(!TERMs_typing(ctx, stmt, FOREACH_name, abr, ns, type, TWARN_)) {
 		return NULL;
 	}
-	knh_class_t itrcid = knh_class_Iterator(ctx, TERMs_getcid(stmt, FOREACH_name));
+	itrcid = knh_class_Iterator(ctx, TERMs_getcid(stmt, FOREACH_name));
 	if(!TERMs_typing(ctx, stmt, FOREACH_iter, abr, ns, NNTYPE_cid(itrcid), TITERCONV_)) {
 		//DBG2_P("No mapper, using opItr");
 		Stmt *stmt_call = new_Stmt(ctx, 0, STT_CALL);
@@ -2742,23 +2740,26 @@ Term *knh_StmtFOREACH_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 	}
 
 	L_BLOCK:;
-	int sfpidx = knh_Asm_declareVariable(ctx, abr, 0, TYPE_Any,
-			knh_tName_local(ctx, "__S%d__", DP(abr)->level), KNH_NULL);
-	//DBG2_P("sfpidx=%d", sfpidx);
-	if(sfpidx == -1) return NULL;
-	Token *tkitr = new_TokenNULL(ctx, FL(stmt), itrcid);
-	knh_Token_toSTACK(ctx, tkitr, sfpidx, itrcid);
-	knh_Stmt_add(ctx, stmt, TM(tkitr));
+	KNH_ASSERT(itrcid != CLASS_unknown);
+	{
+		int sfpidx = knh_Asm_declareVariable(ctx, abr, 0, TYPE_Any,
+				knh_tName_local(ctx, "__S%d__", DP(abr)->level), KNH_NULL);
+		//DBG2_P("sfpidx=%d", sfpidx);
+		if(sfpidx == -1) return NULL;
+		Token *tkitr = new_TokenNULL(ctx, FL(stmt), itrcid);
+		knh_Token_toSTACK(ctx, tkitr, sfpidx, itrcid);
+		knh_Stmt_add(ctx, stmt, TM(tkitr));
 
-	if(!TERMs_typing(ctx, stmt, FOREACH_where, abr, ns, NNTYPE_Boolean, TCHECK_)) {
-		return NULL;
-	}
-	if(TERMs_isFALSE(stmt, FOREACH_where)) {
-		knh_Stmt_done(ctx, stmt);
+		if(!TERMs_typing(ctx, stmt, FOREACH_where, abr, ns, NNTYPE_Boolean, TCHECK_)) {
+			return NULL;
+		}
+		if(TERMs_isFALSE(stmt, FOREACH_where)) {
+			knh_Stmt_done(ctx, stmt);
+			return TM(stmt);
+		}
+		TERMs_typingBLOCK(ctx, stmt, FOREACH_loop, abr, ns);
 		return TM(stmt);
 	}
-	TERMs_typingBLOCK(ctx, stmt, FOREACH_loop, abr, ns);
-	return TM(stmt);
 }
 
 /* ------------------------------------------------------------------------ */
@@ -3270,8 +3271,8 @@ static
 void knh_Asm_declareClassField(Ctx *ctx, Asm *abr, knh_class_t cid)
 {
 	knh_ClassTable_t *TC = (knh_ClassTable_t*)(&ctx->share->ClassTable[cid]);
-	DEBUG3_ASSERT(IS_ClassStruct(TC->cstruct));
-	DEBUG3_ASSERT((TC->cstruct)->fields == NULL);
+	DBG2_ASSERT(IS_ClassStruct(TC->cstruct));
+	DBG2_ASSERT((TC->cstruct)->fields == NULL);
 	{
 		int i, fsize = DP(abr)->vars_size;
 		knh_cfield_t *cf = (knh_cfield_t*)KNH_MALLOC(ctx, sizeof(knh_cfield_t) * fsize);
