@@ -53,7 +53,6 @@ static char* knh_token_array_tochar[] = {
     "mapmap",  /* mapmap */ 
     "weave",  /* weave */ 
     "aspect",  /* aspect */ 
-    "block",  /* block */ 
     "if",  /* if */ 
     "else",  /* else */ 
     "switch",  /* switch */ 
@@ -184,7 +183,6 @@ static knh_methodn_t knh_token_array_tomethodn[] = {
     METHODN_NONAME,  /* mapmap */ 
     METHODN_NONAME,  /* weave */ 
     METHODN_NONAME,  /* aspect */ 
-    METHODN_NONAME,  /* block */ 
     METHODN_NONAME,  /* if */ 
     METHODN_NONAME,  /* else */ 
     METHODN_NONAME,  /* switch */ 
@@ -315,7 +313,6 @@ static int knh_token_array_getOpPriority[] = {
     0,  /* mapmap */ 
     0,  /* weave */ 
     0,  /* aspect */ 
-    0,  /* block */ 
     0,  /* if */ 
     0,  /* else */ 
     0,  /* switch */ 
@@ -446,7 +443,6 @@ static int knh_token_array_getOpSize[] = {
     0,  /* mapmap */ 
     0,  /* weave */ 
     0,  /* aspect */ 
-    0,  /* block */ 
     0,  /* if */ 
     0,  /* else */ 
     0,  /* switch */ 
@@ -577,7 +573,6 @@ static knh_bool_t knh_token_array_isEndOfStmt[] = {
     1,  /* mapmap */ 
     1,  /* weave */ 
     1,  /* aspect */ 
-    1,  /* block */ 
     1,  /* if */ 
     1,  /* else */ 
     1,  /* switch */ 
@@ -835,7 +830,6 @@ Token *new_Token__parse(Ctx *ctx, knh_flag_t flag, InputStream *in, knh_bytes_t
         if(ISB(t, "as")) { tt = TT_AS; break; }
     break;
     case 'b':
-        if(ISB(t, "block")) { tt = TT_BLOCK; break; }
         if(ISB(t, "break")) { tt = TT_BREAK; break; }
         if(ISB(t, "boolean")) { t = STEXT("Boolean!"); goto L_TAIL; }
     break;
